@@ -35,6 +35,7 @@ from ..usecases.traffic_sign_monitoring import TrafficSignMonitoringConfig, Traf
 from ..usecases.crop_weed_detection import CropWeedDetectionUseCase, CropWeedDetectionConfig
 from ..usecases.child_monitoring import ChildMonitoringUseCase, ChildMonitoringConfig
 from ..usecases.gender_detection import GenderDetectionConfig, GenderDetectionUseCase
+from ..usecases.weapon_detection import WeaponDetectionUseCase,WeaponDetectionConfig
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -67,6 +68,7 @@ __all__ = [
     'CropWeedDetectionUseCase',
     'ChildMonitoringUseCase',
     'GenderDetectionUseCase',
+    'WeaponDetectionUseCase',
 
 
 
@@ -100,5 +102,6 @@ __all__ = [
     'TrafficSignMonitoringConfig',
     'CropWeedDetectionConfig',
     'ChildMonitoringConfig',
-    'GenderDetectionConfig'
+    'GenderDetectionConfig',
+    'WeaponDetectionConfig',
 ]
