@@ -413,6 +413,7 @@ class ConfigManager:
             "emergency_vehicle_detection": None,
             "price_tag_detection": None,
             "child_monitoring": None,
+            "weapon_tracking" : None
         }
 
     def register_config_class(self, usecase: str, config_class: type) -> None:
@@ -451,6 +452,14 @@ class ConfigManager:
         except ImportError:
             return None
         
+    def weapon_tracking_config_class(self):
+        """Get  weapon detection class to avoid circular imports."""
+        try:
+            from ..usecases.weapon_detection import WeaponDetectionConfig
+            return WeaponDetectionConfig
+        except ImportError:
+            return None
+        
     def traffic_sign_monitoring_config_class(self):
         """Get traffic sign monitoring class to avoid circular imports."""
         try:
@@ -875,6 +884,22 @@ class ConfigManager:
                 **kwargs
             )
 
+        elif usecase == "weapon_tracking":
+            # Import here to avoid circular import
+            from ..usecases.weapon_detection import WeaponDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = WeaponDetectionConfig(
+                category=category or "security",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+
         elif usecase == "traffic_sign_monitoring ":
             # Import here to avoid circular import
             from ..usecases.traffic_sign_monitoring import TrafficSignMonitoringConfig
@@ -1296,6 +1321,12 @@ class ConfigManager:
             default_config = TheftDetectionConfig()
             return default_config.to_dict()
         
+        elif usecase == "weapon_tracking":
+            # Import here to avoid circular import
+            from ..usecases.weapon_detection import WeaponDetectionConfig
+            default_config = WeaponDetectionConfig()
+            return default_config.to_dict()
+        
         elif usecase == "weld_defect_detection":
             # Import here to avoid circular import
             from ..usecases.weld_defect_detection import WeldDefectConfig
