@@ -37,6 +37,7 @@ from .theft_detection import TheftDetectionConfig , TheftDetectionUseCase
 from .crop_weed_detection import CropWeedDetectionConfig, CropWeedDetectionUseCase
 from .child_monitoring import ChildMonitoringUseCase, ChildMonitoringConfig
 from .gender_detection import GenderDetectionUseCase, GenderDetectionConfig
+from .weapon_detection import WeaponDetectionConfig,WeaponDetectionUseCase
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -60,6 +61,7 @@ __all__ = [
     'AgeDetectionUseCase',
     'WeldDefectUseCase',
     'PriceTagUseCase',
+    'WeaponDetectionUseCase',
     'TheftDetectionUseCase',
     'TrafficSignMonitoringUseCase',
     'DistractedDriverUseCase',
@@ -98,5 +100,6 @@ __all__ = [
     'SolarPanelConfig',
     'CropWeedDetectionConfig',
     'ChildMonitoringConfig',
-    'GenderDetectionConfig'
+    'GenderDetectionConfig',
+    'WeaponDetectionConfig',
 ]
\ No newline at end of file
