@@ -470,11 +470,11 @@ class EmergencyVehicleUseCase(BaseProcessor):
             # Generate human text in new format
             human_text_lines = ["EVENTS DETECTED:"]
             # \t , not sure if it affects template 
-            human_text_lines.append(f"    - {total_vehicles} Vehicle(s) detected [INFO]")
+            human_text_lines.append(f"    - {total_vehicles} Emergency Vehicle(s) detected [INFO]")
             human_text = "\n".join(human_text_lines)
 
             event = {
-                "type": "vehicle_monitoring",
+                "type": "emergency_vehicle_detection",
                 "stream_time": datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S UTC"),
                 "level": level,
                 "intensity": round(intensity, 1),
